@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-05'; # DATE
-our $VERSION = '0.89'; # VERSION
+our $DATE = '2015-03-07'; # DATE
+our $VERSION = '0.90'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1142,7 +1142,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.89 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-05.
+This document describes version 0.90 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
 
 =head1 DESCRIPTION
 
@@ -1208,19 +1208,20 @@ subcommand spec is filled from the attributes, e.g. C<url>, C<summary>, <tags>,
 and so on.
 
 We then perform a C<meta> Riap request to the URL to get the Rinci metadata.
-From the Rinci metadata we get list of arguments (the C<args> property). From
-this, we generate a spec of command-line options to feed to L<Getopt::Long>.
-There are some conversions being done, e.g. an argument called C<foo_bar> will
-become command-line option C<--foo-bar>. Command-line aliases from metadata are
-also added to the C<Getopt::Long> spec.
+After that, C<hook_after_get_meta> is run if provided. From the Rinci metadata
+we get list of arguments (the C<args> property). From this, we generate a spec
+of command-line options to feed to L<Getopt::Long>. There are some conversions
+being done, e.g. an argument called C<foo_bar> will become command-line option
+C<--foo-bar>. Command-line aliases from metadata are also added to the
+C<Getopt::Long> spec.
 
 It is also at this step that we read config file (if C<read_config> attribute is
-true). We run B<hook_before_read_config_file> first. Some ideas to do in this
+true). We run C<hook_before_read_config_file> first. Some ideas to do in this
 hook: setting default config profile.
 
 We then pass the spec to C<Getopt::Long::GetOptions>, we get function arguments.
 
-We then run B<hook_after_parse_argv>. Some ideas to do in this hook: XXX.
+We then run C<hook_after_parse_argv>. Some ideas to do in this hook: XXX.
 
 Function arguments that are still missing can be filled from STDIN or files, if
 the metadata specifies C<cmdline_src> property (see L<Rinci::function> for more
@@ -1921,7 +1922,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
