@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-03-05'; # DATE
-our $VERSION = '0.89'; # VERSION
+our $DATE = '2015-03-07'; # DATE
+our $VERSION = '0.90'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -377,6 +377,17 @@ sub hook_after_get_meta {
             },
         };
     }
+
+    # check deps property. XXX this should be done only when we don't wrap
+    # subroutine, because Perinci::Sub::Wrapper already checks the deps
+    # property.
+    if ($r->{meta}{deps}) {
+        require Perinci::Sub::DepChecker;
+        my $res = Perinci::Sub::DepChecker::check_deps($r->{meta}{deps});
+        if ($res) {
+            die [412, "Dependency failed: $res"];
+        }
+    }
 }
 
 sub run_subcommands {
@@ -491,7 +502,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.89 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-05.
+This document describes version 0.90 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
 
 =head1 SYNOPSIS
 
@@ -593,7 +604,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
